==> trial_quota_v1.1.tar.gz: trial_quota_v1.1/trial_quota.tcl <==
#!/usr/bin/tclsh

#############
# TRIAL QUOTA v1.0 (C) vip3r@i386.net / wh3e@hugbox.net
#############

# Location where the log file is.
set trial_file "/glftpd/ftp-data/logs/trial"

# Trigger to list all trials
set trial_list "!mvtrials"

# Where the trial list script is located
set trial_list_script {/glftpd/bin/trials.sh}

# Tag to use for trial
set trial_tag "\[-MV-TRIAL-\]"

# Tag to use for quota
set quota_tag "\[-MV-QUOTA-\]"

# Trigger to use for checking quota
set quotatrigger "!mvpassed"

# Where the quota script is located
set quotabin {/glftpd/bin/quota.sh}

# Trigger to use to check trial
set trialqtrigger "!mvtrial"

# Where the trial quota script is located
set trialqbin {/glftpd/bin/trial.sh}
                                                                                                                                                                                   
# Trigger to use for the quota list
set quotalisttrigger !mvquotalist
                                                                                                                                                                                   
# Where the quota list script is located
set qlbinary {/glftpd/bin/quotas.sh}

#Might need to change FEB! It was 2004 when I wrote this.
set JAN "31"
set FEB "29"
set MAR "31"
set APR "30"
set MAY "31"
set JUN "30"
set JUL "31"
set AUG "31"
set SEP "30"
set OCT "31"
set NOV "30"
set DEC "31"

# Change the flags if you want to.
# -|- = All users
# o-o = Users with +o flags
bind pub -|- $quotatrigger  quotacheck
bind pub o-o $trial_list trial_list
bind pub -|- $trialqtrigger check_q_trial
bind pub o|o $quotalisttrigger quotalist

#### No need to edit below this line ####

proc trial_list {nick uhost hand chan arg} {
global trial_file trial_list_script trial_tag
	set output [exec $trial_list_script]
	set trialindex "first"
	catch {open $trial_file r} fileid
	putserv "PRIVMSG $chan :$trial_tag CURRENT USERS ON TRiAL! 2000Mb/7DAYS"
	while {![eof $fileid]} { 
		if {($trialindex == "done")} {
			set trialuser [gets $fileid]
			set trialnick [lindex [split $trialuser |] 0]
			set passline [lindex [split $trialuser |] 1]
			set currenttime [exec date]
			if {($passline != "")} {
				set username [lindex [split $passline :] 0]
				set password [lindex [split $passline :] 1]
				set uid [lindex [split $passline :] 2]
				set guid [lindex [split $passline :] 3]
				set adddate [lindex [split $passline :] 4]
				set homedir [lindex [split $passline :] 5]
				set bash1 [lindex [split $passline :] 6]
				set adddate [split $adddate "\n"]

				set addm [lindex [split $adddate -] 0]
				set addd [lindex [split $adddate -] 1]
				set addy [lindex [split $adddate -] 2]
				set realdate [clock scan $currenttime]
				set adddate [clock scan $addy-$addm-$addd]
				set days [expr $realdate - $adddate]
				set days [expr $days / 60]
				set days [expr $days / 60]
				set days [expr $days / 24]
				putserv "PRIVMSG $chan :$trial_tag $trialnick Day:$days/7"
			}
		}
		set trialindex "done"
	}
	close $fileid
}

proc quotacheck {nick output binary chan text} {
global JAN FEB MAR APR MAY JUN JUL AUG SEP OCT NOV DEC quotabin quota_tag
        set todaysdate [exec date]
        set notneeded [lindex [split $todaysdate " "] 0]
        set MONTH [lindex [split $todaysdate " "] 1]
        set DAY [lindex [split $todaysdate " "] 2]
        if {$MONTH == "Jan"} { set DAYS $JAN }
        if {$MONTH == "Feb"} { set DAYS $FEB }
        if {$MONTH == "Mar"} { set DAYS $MAR }
        if {$MONTH == "Apr"} { set DAYS $APR }
        if {$MONTH == "May"} { set DAYS $MAY }
        if {$MONTH == "Jun"} { set DAYS $JUN }
        if {$MONTH == "Jul"} { set DAYS $JUL }
        if {$MONTH == "Aug"} { set DAYS $AUG }
        if {$MONTH == "Sep"} { set DAYS $SEP }
        if {$MONTH == "Oct"} { set DAYS $OCT }
        if {$MONTH == "Nov"} { set DAYS $NOV }
        if {$MONTH == "Dec"} { set DAYS $DEC }
        set DAYSLEFT [expr $DAYS - $DAY]
        set QUOTACHECK [exec $quotabin $text]
        set QUOTALINE [lindex [split $QUOTACHECK " "] 1]
        if {$QUOTALINE == "have"} {
                putquick "PRIVMSG $chan :$quota_tag [exec $quotabin $text] With $DAYSLEFT day(s) left."
        } else {
                putquick "PRIVMSG $chan :$quota_tag [exec $quotabin $text]"
        }
}

proc check_q_trial {nick uhost hand chan arg} {
global trialqbin trial_tag
        set output [exec $trialqbin $arg]
        set trialnick [lindex [split $output |] 0]
        set passline [lindex [split $output |] 1]
        set currenttime [exec date]
        if {($passline != "")} {
                set username [lindex [split $passline :] 0]
                set password [lindex [split $passline :] 1]
                set uid [lindex [split $passline :] 2]
                set guid [lindex [split $passline :] 3]
                set adddate [lindex [split $passline :] 4]
                set homedir [lindex [split $passline :] 5]
                set bash1 [lindex [split $passline :] 6]
                set adddate [split $adddate "\n"]
                set addm [lindex [split $adddate -] 0]
                set addd [lindex [split $adddate -] 1]
                set addy [lindex [split $adddate -] 2]
                set realdate [clock scan $currenttime]
                set adddate [clock scan $addy-$addm-$addd]
                set days [expr $realdate - $adddate]
                set days [expr $days / 60]
                set days [expr $days / 60]
                set days [expr $days / 24]
                if {($days == "-1")} { set days 0 }
                putserv "PRIVMSG $chan :$trial_tag $trialnick Day:$days/7"
        } else {
                putserv "PRIVMSG $chan :$trial_tag $output"
        }
}

proc quotalist {nick uhost hand chan arg} {
global quota_tag quotalisttrigger qlbinary JAN FEB MAR APR MAY JUN JUL AUG SEP OCT NOV DEC
        set user1 ""
        set user2 ""
        set user3 ""
        set user4 ""
        set todaysdate [exec date]
        set notneeded [lindex [split $todaysdate " "] 0]
        set MONTH [lindex [split $todaysdate " "] 1]
        set DAY [lindex [split $todaysdate " "] 2]
        if {$MONTH == "Jan"} { set DAYS $JAN }
        if {$MONTH == "Feb"} { set DAYS $FEB }
        if {$MONTH == "Mar"} { set DAYS $MAR }
        if {$MONTH == "Apr"} { set DAYS $APR }
        if {$MONTH == "May"} { set DAYS $MAY }
        if {$MONTH == "Jun"} { set DAYS $JUN }
        if {$MONTH == "Jul"} { set DAYS $JUL }
        if {$MONTH == "Aug"} { set DAYS $AUG }
        if {$MONTH == "Sep"} { set DAYS $SEP }
        if {$MONTH == "Oct"} { set DAYS $OCT }
        if {$MONTH == "Nov"} { set DAYS $NOV }
        if {$MONTH == "Dec"} { set DAYS $DEC }
        set DAYSLEFT [expr $DAYS - $DAY]
        if {($arg != "passed") && ($arg != "failed")} {
                putserv "PRIVMSG $nick :$quota_tag Use $quotalisttrigger <passed/failed>. Script is case sensetive."
        } else {
                putserv "PRIVMSG $nick :$quota_tag Users that $arg quota! $DAYSLEFT day(s) left."
                foreach listline [split [exec $qlbinary $arg] "\n"] {
                        if {$user1 == ""} {
                        set user1 $listline
                        } elseif {$user2 == ""} {
                        set user2 $listline
                        } elseif {$user3 == ""} {
                        set user3 $listline
                        } elseif {$user4 == ""} {
                        set user4 $listline
                        putserv "PRIVMSG $nick :$quota_tag $user1 \| $user2 \| $user3 \| $user4"
                        set user1 ""
                        set user2 ""
                        set user3 ""
                        set user4 ""
                        }
                }
                if {$user1 == ""} {
                        putserv "PRIVMSG $nick :$quota_tag End of list."
                } elseif {$user2 == ""} {
                        putserv "PRIVMSG $nick :$quota_tag $user1"
                        putserv "PRIVMSG $nick :$quota_tag End of list."
                } elseif {$user3 == ""} {
                        putserv "PRIVMSG $nick :$quota_tag $user1 \| $user2"
                        putserv "PRIVMSG $nick :$quota_tag End of list."
                } elseif {$user4 == ""} {
                        putserv "PRIVMSG $nick :$quota_tag $user1 \| $user2 \| $user3"
                        putserv "PRIVMSG $nick :$quota_tag End of list."
                }
        }
}

putlog "trial quota v1.0 by vip3r and wh3e loaded"

==> trial_quota_v1.2.tar.gz: trial_quota_v1.2/trial_quota.tcl <==
#!/usr/bin/tclsh

#############
# TRIAL QUOTA v1.2 (C) vip3r@i386.net / wh3e@hugbox.net
#############

# Location where the log file is.
set trial_file "/glftpd/ftp-data/logs/trial"

# Trigger to list all trials
set trial_list "!trials"

# Where the trial list script is located
set trial_list_script {/glftpd/bin/trials.sh}

# Tag to use for trial
set trial_tag "\[-TRIAL-\]"

# Tag to use for quota
set quota_tag "\[-QUOTA-\]"

# Trigger to use for checking quota
set quotatrigger "!passed"

# Where the quota script is located
set quotabin {/glftpd/bin/quota.sh}

# Trigger to use to check trial
set trialqtrigger "!trial"

# Where the trial quota script is located
set trialqbin {/glftpd/bin/trial.sh}
                                                                                                                                                                                   
# Trigger to use for the quota list
set quotalisttrigger !quotalist
                                                                                                                                                                                   
# Where the quota list script is located
set qlbinary {/glftpd/bin/quotas.sh}

#Might need to change FEB! It was 2004 when I wrote this.
set JAN "31"
set FEB "29"
set MAR "31"
set APR "30"
set MAY "31"
set JUN "30"
set JUL "31"
set AUG "31"
set SEP "30"
set OCT "31"
set NOV "30"
set DEC "31"

# Change the flags if you want to.
# -|- = All users
# o-o = Users with +o flags
bind pub -|- $quotatrigger  quotacheck
bind pub o-o $trial_list trial_list
bind pub -|- $trialqtrigger check_q_trial
bind pub o|o $quotalisttrigger quotalist

#### No need to edit below this line ####

proc trial_list {nick uhost hand chan arg} {
global trial_file trial_list_script trial_tag
	set output [exec $trial_list_script]
	set trialindex "first"
	catch {open $trial_file r} fileid
	putserv "PRIVMSG $chan :$trial_tag CURRENT USERS ON TRiAL! 2000Mb/7DAYS"
	while {![eof $fileid]} { 
		if {($trialindex == "done")} {
			set trialuser [gets $fileid]
			set trialnick [lindex [split $trialuser |] 0]
			set passline [lindex [split $trialuser |] 1]
			set currenttime [exec date]
			if {($passline != "")} {
				set username [lindex [split $passline :] 0]
				set password [lindex [split $passline :] 1]
				set uid [lindex [split $passline :] 2]
				set guid [lindex [split $passline :] 3]
				set adddate [lindex [split $passline :] 4]
				set homedir [lindex [split $passline :] 5]
				set bash1 [lindex [split $passline :] 6]
				set adddate [split $adddate "\n"]

				set addm [lindex [split $adddate -] 0]
				set addd [lindex [split $adddate -] 1]
				set addy [lindex [split $adddate -] 2]
				set realdate [clock scan $currenttime]
				set adddate [clock scan $addy-$addm-$addd]
				set days [expr $realdate - $adddate]
				set days [expr $days / 60]
				set days [expr $days / 60]
				set days [expr $days / 24]
				putserv "PRIVMSG $chan :$trial_tag $trialnick Day:$days/7"
			}
		}
		set trialindex "done"
	}
	close $fileid
}

proc quotacheck {nick output binary chan text} {
global JAN FEB MAR APR MAY JUN JUL AUG SEP OCT NOV DEC quotabin quota_tag
        set todaysdate [exec date]
        set notneeded [lindex [split $todaysdate " "] 0]
        set MONTH [lindex [split $todaysdate " "] 1]
        set DAY [lindex [split $todaysdate " "] 2]
        if {$MONTH == "Jan"} { set DAYS $JAN }
        if {$MONTH == "Feb"} { set DAYS $FEB }
        if {$MONTH == "Mar"} { set DAYS $MAR }
        if {$MONTH == "Apr"} { set DAYS $APR }
        if {$MONTH == "May"} { set DAYS $MAY }
        if {$MONTH == "Jun"} { set DAYS $JUN }
        if {$MONTH == "Jul"} { set DAYS $JUL }
        if {$MONTH == "Aug"} { set DAYS $AUG }
        if {$MONTH == "Sep"} { set DAYS $SEP }
        if {$MONTH == "Oct"} { set DAYS $OCT }
        if {$MONTH == "Nov"} { set DAYS $NOV }
        if {$MONTH == "Dec"} { set DAYS $DEC }
        set DAYSLEFT [expr $DAYS - $DAY]
        set QUOTACHECK [exec $quotabin $text]
        set QUOTALINE [lindex [split $QUOTACHECK " "] 1]
        if {$QUOTALINE == "have"} {
                putquick "PRIVMSG $chan :$quota_tag [exec $quotabin $text] With $DAYSLEFT day(s) left."
        } else {
                putquick "PRIVMSG $chan :$quota_tag [exec $quotabin $text]"
        }
}

proc check_q_trial {nick uhost hand chan arg} {
global trialqbin trial_tag
        set output [exec $trialqbin $arg]
        set trialnick [lindex [split $output |] 0]
        set passline [lindex [split $output |] 1]
        set currenttime [exec date]
        if {($passline != "")} {
                set username [lindex [split $passline :] 0]
                set password [lindex [split $passline :] 1]
                set uid [lindex [split $passline :] 2]
                set guid [lindex [split $passline :] 3]
                set adddate [lindex [split $passline :] 4]
                set homedir [lindex [split $passline :] 5]
                set bash1 [lindex [split $passline :] 6]
                set adddate [split $adddate "\n"]
                set addm [lindex [split $adddate -] 0]
                set addd [lindex [split $adddate -] 1]
                set addy [lindex [split $adddate -] 2]
                set realdate [clock scan $currenttime]
                set adddate [clock scan $addy-$addm-$addd]
                set days [expr $realdate - $adddate]
                set days [expr $days / 60]
                set days [expr $days / 60]
                set days [expr $days / 24]
                if {($days == "-1")} { set days 0 }
                putserv "PRIVMSG $chan :$trial_tag $trialnick Day:$days/7"
        } else {
                putserv "PRIVMSG $chan :$trial_tag $output"
        }
}

proc quotalist {nick uhost hand chan arg} {
global quota_tag quotalisttrigger qlbinary JAN FEB MAR APR MAY JUN JUL AUG SEP OCT NOV DEC
        set user1 ""
        set user2 ""
        set user3 ""
        set user4 ""
        set todaysdate [exec date]
        set notneeded [lindex [split $todaysdate " "] 0]
        set MONTH [lindex [split $todaysdate " "] 1]
        set DAY [lindex [split $todaysdate " "] 2]
        if {$MONTH == "Jan"} { set DAYS $JAN }
        if {$MONTH == "Feb"} { set DAYS $FEB }
        if {$MONTH == "Mar"} { set DAYS $MAR }
        if {$MONTH == "Apr"} { set DAYS $APR }
        if {$MONTH == "May"} { set DAYS $MAY }
        if {$MONTH == "Jun"} { set DAYS $JUN }
        if {$MONTH == "Jul"} { set DAYS $JUL }
        if {$MONTH == "Aug"} { set DAYS $AUG }
        if {$MONTH == "Sep"} { set DAYS $SEP }
        if {$MONTH == "Oct"} { set DAYS $OCT }
        if {$MONTH == "Nov"} { set DAYS $NOV }
        if {$MONTH == "Dec"} { set DAYS $DEC }
        set DAYSLEFT [expr $DAYS - $DAY]
        if {($arg != "passed") && ($arg != "failed")} {
                putserv "PRIVMSG $nick :$quota_tag Use $quotalisttrigger <passed/failed>. Script is case sensetive."
        } else {
                putserv "PRIVMSG $nick :$quota_tag Users that $arg quota! $DAYSLEFT day(s) left."
                foreach listline [split [exec $qlbinary $arg] "\n"] {
                        if {$user1 == ""} {
                        set user1 $listline
                        } elseif {$user2 == ""} {
                        set user2 $listline
                        } elseif {$user3 == ""} {
                        set user3 $listline
                        } elseif {$user4 == ""} {
                        set user4 $listline
                        putserv "PRIVMSG $nick :$quota_tag $user1 \| $user2 \| $user3 \| $user4"
                        set user1 ""
                        set user2 ""
                        set user3 ""
                        set user4 ""
                        }
                }
                if {$user1 == ""} {
                        putserv "PRIVMSG $nick :$quota_tag End of list."
                } elseif {$user2 == ""} {
                        putserv "PRIVMSG $nick :$quota_tag $user1"
                        putserv "PRIVMSG $nick :$quota_tag End of list."
                } elseif {$user3 == ""} {
                        putserv "PRIVMSG $nick :$quota_tag $user1 \| $user2"
                        putserv "PRIVMSG $nick :$quota_tag End of list."
                } elseif {$user4 == ""} {
                        putserv "PRIVMSG $nick :$quota_tag $user1 \| $user2 \| $user3"
                        putserv "PRIVMSG $nick :$quota_tag End of list."
                }
        }
}

putlog "trial quota v1.2 by vip3r and wh3e loaded"
